@@ -1,5 +1,5 @@
 # Copyright 2021-2023 Datum Technology Corporation
-# SPDX-License-Identifier: GPL-3.0-or-later
+# SPDX-License-Identifier: GPL-3.0
 ########################################################################################################################
 
 
@@ -316,7 +316,13 @@ def create_sim_job(cli_args):
 
 
 def create_repeat_sim_job(cli_args):
-    last_cli_args = get_last_job()
+    last_cli_args = get_last_sim_job()
+    repeat_str = ""
+    for arg in last_cli_args:
+        repeat_str = f"{repeat_str} {arg}"
+    repeat_str = repeat_str.strip()
+    common.banner(f"Repeating `mio {repeat_str}`")
+    
     parser        = build_parser()
     sim_args      = parser.parse_args(last_cli_args)
     sim_job = create_sim_job(sim_args)
@@ -373,7 +379,7 @@ def get_last_job():
         with open(cfg.commands_file_path, 'r') as yaml_file_read:
             ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
             timestamps = sorted(ymlr)
-            common.dbg(str(ymlr[timestamps[-1]]))
+            #common.dbg(str(ymlr[timestamps[-1]]))
             job = ymlr[timestamps[-1]]
             job.pop(0)
             return job
@@ -381,6 +387,24 @@ def get_last_job():
         common.fatal("Failed to load command history from disk: " + str(e))
 
 
+def get_last_sim_job():
+    try:
+        if not os.path.exists(cfg.commands_file_path):
+            common.fatal(f"No command history exists!")
+        with open(cfg.commands_file_path, 'r') as yaml_file_read:
+            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
+            timestamps = sorted(ymlr)
+            timestamps.reverse()
+            for timestamp in timestamps:
+                #common.dbg(str(ymlr[timestamp]))
+                job = ymlr[timestamp]
+                job.pop(0)
+                if 'sim' in job:
+                    return job
+    except Exception as e:
+        common.fatal("Failed to load command history from disk: " + str(e))
+
+
 
 def log_cli_args_to_disk():
     if "!" in sys.argv:
