@@ -1,5 +1,5 @@
 # Copyright 2021-2023 Datum Technology Corporation
-# SPDX-License-Identifier: GPL-3.0-or-later
+# SPDX-License-Identifier: GPL-3.0
 ########################################################################################################################
 
 from mio import common
@@ -313,7 +313,8 @@ def insert_key_checks(location, ip, org_id, ip_id, ip_key):
         if (file_path[-2:] == ".v") or (file_path[-3:] == ".vh") or (file_path[-3:] == ".sv") or (file_path[-4:] == ".svh"):  # TODO Add support for VHDL files
             try:
                 with open(file_path, "r") as file_o:
-                    replacement_text = f"uvml_mio_lic_pkg::uvml_mio_lic_server_c::check_key(\"{ip_vendor}/{ip_name}/{file}\", \"{ip_id}\", \"{org_id}\", \"{ip_key}\");"
+                    file_pretty = file.replace(location, "")
+                    replacement_text = f"uvml_mio_lic_pkg::uvml_mio_lic_server_c::check_key(\"{ip_vendor}/{ip_name}/{file_pretty}\", \"{ip_id}\", \"{org_id}\", \"{ip_key}\");"
                     content = file_o.read().replace(text_to_search, replacement_text)
                 file_o = open(file_path, "w")
                 file_o.write(content)
